#include <QGuiApplication>
#include <QQmlApplicationEngine>
#include <QQmlContext>
#include <QDebug>
#include <KDNSSD/DNSSD/RemoteService>
#include <QPointer>

typedef QMap<QString, QByteArray> TextMap;

class TextObject : public QObject
{
    Q_OBJECT
    Q_PROPERTY(QString key MEMBER key CONSTANT)
    Q_PROPERTY(QString value MEMBER value CONSTANT)
public:
    TextObject(const QString &k, const QString &v)
        : QObject()
        , key(k)
        , value(v)
    {}

    QString key;
    QString value;
};

class Service : public KDNSSD::RemoteService
{
    Q_OBJECT
    Q_PROPERTY(QString domain READ domain)
    Q_PROPERTY(QString hostName READ hostName)
    Q_PROPERTY(unsigned short port READ port)
    Q_PROPERTY(QString serviceName READ serviceName)
    Q_PROPERTY(QList<QObject *> textData READ textDataVariant)
    Q_PROPERTY(QString type READ type)
public:
    using KDNSSD::RemoteService::RemoteService;

    QList<QObject *> textDataVariant()
    {
        if (!m_initialized) {
            const auto data = textData();
            for (auto it = data.constBegin(); it != data.constEnd(); ++it) {
                QPointer<TextObject> ptr(new TextObject(it.key(), it.value()));
                m_textList << ptr;
                m_list << ptr;
            }
            m_initialized = true;
        }

        return m_list;
    }

    QList<QPointer<TextObject>> m_textList;
    QList<QObject *> m_list;

    bool m_initialized = false;
};

int main(int argc, char *argv[])
{
    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);

    QGuiApplication app(argc, argv);

    QString domain = "local";
    QString type = "_ipps._tcp";
    QString serviceName = "HP LaserJet P2055d @ panda";
    if (app.arguments().size() > 1) {
        QUrl url(app.arguments().at(1));
        url = url.adjusted(QUrl::NormalizePathSegments);
        auto parts = url.path().split("/", QString::SkipEmptyParts);
        qDebug() << parts;
        Q_ASSERT(parts.size() == 3);

        domain = parts.at(0);
        type = parts.at(1);
        serviceName = parts.at(2);
    }

    // kndssd://local/_ipps._tcp/HP LaserJet P2055d @ panda
    Service service(serviceName, type, domain);
    service.resolve();

    QQmlApplicationEngine engine;
    const QUrl url(QStringLiteral("qrc:/main.qml"));
    QObject::connect(&engine, &QQmlApplicationEngine::objectCreated,
                     &app, [url](QObject *obj, const QUrl &objUrl) {
        if (!obj && url == objUrl)
            QCoreApplication::exit(-1);
    }, Qt::QueuedConnection);
    engine.load(url);
    engine.rootContext()->setContextProperty("service", &service);

    return app.exec();
}

#include "main.moc"
